@@ -28,7 +28,7 @@ from manilaclient import client as manila_client
 LOG = logging.getLogger(__name__)
 
 MANILA_UI_USER_AGENT_REPR = "manila_ui_plugin_for_horizon"
-MANILA_VERSION = "2.46"
+MANILA_VERSION = "2.51"
 MANILA_SERVICE_TYPE = "sharev2"
 
 # API static values
@@ -302,10 +302,11 @@ def share_network_list(request, detailed=False, search_opts=None):
 
 
 def share_network_create(request, neutron_net_id=None, neutron_subnet_id=None,
-                         name=None, description=None):
+                         name=None, description=None, availability_zone=None):
     return manilaclient(request).share_networks.create(
         neutron_net_id=neutron_net_id, neutron_subnet_id=neutron_subnet_id,
-        name=name, description=description)
+        name=name, description=description,
+        availability_zone=availability_zone)
 
 
 def share_network_get(request, share_net_id):
@@ -321,6 +322,16 @@ def share_network_delete(request, share_network_id):
     return manilaclient(request).share_networks.delete(share_network_id)
 
 
+def share_network_subnet_create(request, share_network_id=None,
+                                neutron_net_id=None, neutron_subnet_id=None,
+                                availability_zone=None):
+    return manilaclient(request).share_network_subnets.create(
+        share_network_id=share_network_id,
+        neutron_net_id=neutron_net_id,
+        neutron_subnet_id=neutron_subnet_id,
+        availability_zone=availability_zone)
+
+
 def security_service_list(request, search_opts=None):
     return manilaclient(request).security_services.list(
         detailed=True,
@@ -428,6 +439,17 @@ def share_type_create(request, name, spec_driver_handles_share_servers,
         is_public=is_public)
 
 
+def share_type_update(request, share_type_id, name=None, description=None,
+                      is_public=None):
+    share_type_data = {
+        'name': name,
+        'description': description,
+        'is_public': is_public
+    }
+    return manilaclient(request).share_types.get(
+        share_type_id).update(**share_type_data)
+
+
 def share_type_delete(request, share_type_id):
     return manilaclient(request).share_types.delete(share_type_id)
 
