@@ -12,25 +12,25 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from django.conf import urls
+from django.urls import re_path
 
 from manila_ui.dashboards.project.security_services import views
 
 
 urlpatterns = [
-    urls.url(
+    re_path(
         r'^$',
         views.SecurityServicesView.as_view(),
         name='index'),
-    urls.url(
+    re_path(
         r'^create_security_service$',
         views.CreateView.as_view(),
         name='security_service_create'),
-    urls.url(
+    re_path(
         r'^(?P<sec_service_id>[^/]+)/update/$',
         views.UpdateView.as_view(),
         name='security_service_update'),
-    urls.url(
+    re_path(
         r'^(?P<sec_service_id>[^/]+)$',
         views.Detail.as_view(),
         name='security_service_detail'),
