@@ -14,7 +14,7 @@
 
 from django.urls import reverse
 from django.urls import reverse_lazy
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from horizon import exceptions
 from horizon import forms
 from horizon import tables
@@ -172,7 +172,8 @@ class UpdateView(forms.ModalFormView):
         share = self.get_object()
         return {'share_id': self.kwargs["share_id"],
                 'name': share.name,
-                'description': share.description}
+                'description': share.description,
+                'is_public': share.is_public}
 
 
 class UpdateMetadataView(forms.ModalFormView):
@@ -248,6 +249,61 @@ class AddRuleView(forms.ModalFormView):
                        args=[self.kwargs['share_id']])
 
 
+class UpdateRuleMetadataView(forms.ModalFormView):
+    form_class = share_form.UpdateRuleMetadataForm
+    form_id = ""
+    template_name = 'project/shares/update_rule_metadata.html'
+    modal_header = _("Edit Rule Metadata")
+    modal_id = "update_rule_metadata_modal"
+    submit_label = _("Save Changes")
+    submit_url = "horizon:project:shares:update_rule_metadata"
+    success_url = reverse_lazy("horizon:project:shares:index")
+    page_title = _('Edit Rule Metadata')
+
+    def get_object(self):
+        if not hasattr(self, "_object"):
+            rule_id = self.kwargs['rule_id']
+            try:
+                self._object = manila.share_rule_get(self.request, rule_id)
+            except Exception:
+                msg = _('Unable to retrieve share access rule.')
+                url = reverse('horizon:project:shares:manage_rules',
+                              args=[self.initial['share_id']])
+                exceptions.handle(self.request, msg, redirect=url)
+        return self._object
+
+    def get_context_data(self, **kwargs):
+        context = super(UpdateRuleMetadataView, self).\
+            get_context_data(**kwargs)
+        args = (self.get_object().id,)
+        context['submit_url'] = reverse(self.submit_url, args=args)
+        return context
+
+    def get_initial(self):
+        rule = self.get_object()
+        rule_id = self.kwargs["rule_id"]
+        share_id = self.get_share_id(rule_id)
+        return {'rule_id': rule_id,
+                'metadata': rule.metadata,
+                'share_id': share_id}
+
+    def get_success_url(self):
+        rule_id = self.kwargs["rule_id"]
+        share_id = self.get_share_id(rule_id)
+        return reverse("horizon:project:shares:manage_rules", args=[share_id])
+
+    # To redirect to Rules Table page, after updating the rule
+    # metadata. Loop is to get the share_id neccessary to display
+    # Rules Table page.
+    def get_share_id(self, rule_id):
+        shares = manila.share_list(self.request)
+        for share in shares:
+            rules = manila.share_rules_list(self.request, share.id)
+            for rule in rules:
+                if rule.id == rule_id:
+                    return share.id
+
+
 class ManageRulesView(tables.DataTableView):
     table_class = shares_tables.RulesTable
     template_name = 'project/shares/manage_rules.html'
@@ -256,7 +312,6 @@ class ManageRulesView(tables.DataTableView):
         context = super(ManageRulesView, self).get_context_data(**kwargs)
         share = manila.share_get(self.request, self.kwargs['share_id'])
         context['share_display_name'] = share.name or share.id
-        context["share"] = self.get_data()
         context["page_title"] = _("Share Rules: "
                                   "%(share_display_name)s") % {
             'share_display_name': context['share_display_name']}
@@ -272,19 +327,24 @@ class ManageRulesView(tables.DataTableView):
             exceptions.handle(self.request,
                               _('Unable to retrieve share rules.'),
                               redirect=redirect)
+            return []
+
+        for rule in rules:
+            rule.metadata = ui_utils.metadata_to_str(rule.metadata)
+
         return rules
 
 
-class ExtendView(forms.ModalFormView):
-    form_class = share_form.ExtendForm
-    form_id = "extend_share"
-    template_name = 'project/shares/extend.html'
-    modal_header = _("Extend Share")
-    modal_id = "extend_share_modal"
-    submit_label = _("Extend")
-    submit_url = "horizon:project:shares:extend"
+class ResizeView(forms.ModalFormView):
+    form_class = share_form.ResizeForm
+    form_id = "resize_share"
+    template_name = 'project/shares/resize.html'
+    modal_header = _("Resize Share")
+    modal_id = "resize_share_modal"
+    submit_label = _("Resize")
+    submit_url = "horizon:project:shares:resize"
     success_url = reverse_lazy("horizon:project:shares:index")
-    page_title = _('Extend Share')
+    page_title = _('Resize Share')
 
     @memoized.memoized_method
     def get_object(self):
@@ -294,7 +354,7 @@ class ExtendView(forms.ModalFormView):
             exceptions.handle(self.request, _('Unable to retrieve share.'))
 
     def get_context_data(self, **kwargs):
-        context = super(ExtendView, self).get_context_data(**kwargs)
+        context = super(ResizeView, self).get_context_data(**kwargs)
         args = (self.get_object().id,)
         context['submit_url'] = reverse(self.submit_url, args=args)
         try:
@@ -314,7 +374,7 @@ class ExtendView(forms.ModalFormView):
             'share_id': self.kwargs["share_id"],
             'name': share.name or share.id,
             'orig_size': share.size,
-            'new_size': int(share.size) + 1,
+            'new_size': int(share.size),
         }
 
 
