@@ -12,26 +12,19 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import copy
 import ddt
-from django.core.urlresolvers import reverse
-import mock
+from django.urls import reverse
+from unittest import mock
 
 from manila_ui.api import manila as api_manila
-from manila_ui.tests.dashboards.project.shares import test_data
+from manila_ui.tests.dashboards.project import test_data
 from manila_ui.tests import helpers as test
 
 from openstack_dashboard.api import neutron
-from openstack_dashboard.api import nova
 
 SHARE_INDEX_URL = reverse('horizon:admin:shares:index')
 
 
-class FakeAZ(object):
-    def __init__(self, name):
-        self.zoneName = name
-
-
 @ddt.ddt
 class ReplicasTests(test.BaseAdminViewTests):
 
@@ -100,12 +93,6 @@ class ReplicasTests(test.BaseAdminViewTests):
         self.assertFalse(api_manila.share_instance_export_location_list.called)
 
     def test_list(self):
-        old_az = self.share.availability_zone
-        new_az = old_az + "_new"
-        self.mock_object(
-            nova,
-            "availability_zone_list",
-            mock.Mock(return_value=[FakeAZ(new_az), FakeAZ(old_az)]))
         self.mock_object(
             api_manila,
             "share_replica_list",
@@ -123,12 +110,6 @@ class ReplicasTests(test.BaseAdminViewTests):
             mock.ANY, self.share.id)
 
     def test_list_exception(self):
-        old_az = self.share.availability_zone
-        new_az = old_az + "_new"
-        self.mock_object(
-            nova,
-            "availability_zone_list",
-            mock.Mock(return_value=[FakeAZ(new_az), FakeAZ(old_az)]))
         self.mock_object(
             api_manila,
             "share_replica_list",
@@ -158,7 +139,7 @@ class ReplicasTests(test.BaseAdminViewTests):
     @ddt.unpack
     def test_delete_not_allowed(self, replica_list, replica_id,
                                 replication_type):
-        share = copy.copy(self.share)
+        share = test_data.share
         share.replication_type = replication_type
         formData = {"action": "replicas__delete__%s" % replica_id}
         self.mock_object(api_manila, "share_replica_delete")
@@ -190,7 +171,7 @@ class ReplicasTests(test.BaseAdminViewTests):
     )
     @ddt.unpack
     def test_delete_allowed(self, replica_list, replica_id, replication_type):
-        share = copy.copy(self.share)
+        share = test_data.share
         share.replication_type = replication_type
         formData = {"action": "replicas__delete__%s" % replica_id}
         self.mock_object(api_manila, "share_replica_delete")
